@@ -359,25 +359,43 @@ sub _get_desired_caps ( $self, $args ) {
                 '--disable-background-networking',
                 '--disable-client-side-phishing-detection',
                 '--disable-component-update',
-                '--disable-default-apps',
                 '--disable-hang-monitor',
                 '--disable-prompt-on-repost',
                 '--disable-sync',
                 '--disable-web-resources',
 
-                # '--window-size=800x600',
                 '--start-maximized',
+                '--window-size=1280x720',
+
                 '--disable-default-apps',
                 '--no-first-run',
                 '--disable-infobars',
                 '--disable-popup-blocking',
                 '--disable-default-apps',
                 '--disable-web-security',
-                "--user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str,
-                '--no-sandbox',    # required for run under docker
-                defined $useragent ? "--user-agent=$useragent" : (),
+                '--allow-running-insecure-content',
+
+                # logging
+                # '--disable-logging',
+                # '--log-level=0',
+
+                # set user profile dir
+                qq[--user-data-dir=$ENV->{TEMP_DIR}chrome-wds-@{[P->uuid->str]}],
+
+                # required for run under docker
+                '--no-sandbox',
+
+                # user agent
+                defined $useragent ? qq[--user-agent=$useragent] : (),
+
+                # headless mode
                 ( $args->{headless} || !$MSWIN ) && !$self->{wdh}->{xvfb} ? ( '--headless', '--disable-gpu' ) : (),
+
+                # user args
                 $args->{args} ? $args->{args}->@* : (),
+
+                # open "about:blank" by default
+                'about:blank',
             ],
             binary => $args->{bin} // q[],
             prefs => {
@@ -534,7 +552,7 @@ sub _send_cmd ( $self ) {
 ## |======+======================+================================================================================================================|
 ## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (22)                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 379                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
+## |    2 | 392                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
